@@ -1,5 +1,6 @@
 """Some debugging functions for working with the Scrapy engine"""
 
+from __future__ import print_function
 from time import time # used in global tests code
 
 def get_engine_status(engine):
@@ -7,16 +8,15 @@ def get_engine_status(engine):
     global_tests = [
         "time()-engine.start_time",
         "engine.has_capacity()",
-        "len(engine.downloader.slots)",
         "len(engine.downloader.active)",
         "engine.scraper.is_idle()",
     ]
     spider_tests = [
         "engine.spider_is_idle(spider)",
-        "engine.slots[spider].closing",
-        "len(engine.slots[spider].inprogress)",
-        "len(engine.slots[spider].scheduler.dqs or [])",
-        "len(engine.slots[spider].scheduler.mqs)",
+        "engine.slot.closing",
+        "len(engine.slot.inprogress)",
+        "len(engine.slot.scheduler.dqs or [])",
+        "len(engine.slot.scheduler.mqs)",
         "len(engine.scraper.slot.queue)",
         "len(engine.scraper.slot.active)",
         "engine.scraper.slot.active_size",
@@ -28,14 +28,14 @@ def get_engine_status(engine):
     for test in global_tests:
         try:
             status['global'] += [(test, eval(test))]
-        except Exception, e:
+        except Exception as e:
             status['global'] += [(test, "%s (exception)" % type(e).__name__)]
     for spider in engine.slots.keys():
         x = []
         for test in spider_tests:
             try:
                 x += [(test, eval(test))]
-            except Exception, e:
+            except Exception as e:
                 x += [(test, "%s (exception)" % type(e).__name__)]
             status['spiders'][spider] = x
     return status
@@ -53,5 +53,5 @@ def format_engine_status(engine=None):
     return s
 
 def print_engine_status(engine):
-    print format_engine_status(engine)
+    print(format_engine_status(engine))
 
